## [1.0.0] - 2021-11-02
- Published on pypy.org
- Prevent python 3.10.0 as it does not currently work with numpy for this version.

## [0.1.1] - 2021-11-02
- Make README.md images work on pypi.org

## [0.1.0] - 2021-11-02
- No feature changes from previous version.
- Project being properly built with poetry. Restructuring of the source modules.
- Once this is working, there will soon be an 1.0.0 release, also published to pypi.org

## [0.0.4] - 2018-02-02
- New command: list_us_statuses
- Add setup.txt for requirements.
- Small bug fixes.

## [0.0.3] - 2015-12-06
- Major README update on project and features.
- Improve help texts and configuration files.

## [0.0.2] - 2015-12-02
- Minor README updates.

## [0.0.1] - 2015-12-02
- Initial import from other old VCS.
